@@ -15,7 +15,6 @@
 use anyhow::Result;
 use hmac::{Hmac, NewMac};
 use sha2::Sha256;
-use zmq;
 
 pub(crate) type HmacSha256 = Hmac<Sha256>;
 
@@ -30,7 +29,7 @@ impl Connection {
         let mac = if key.is_empty() {
             None
         } else {
-            Some(HmacSha256::new_varkey(key.as_bytes()).expect("Shouldn't fail with HMAC"))
+            Some(HmacSha256::new_from_slice(key.as_bytes()).expect("Shouldn't fail with HMAC"))
         };
         Ok(Connection { socket, mac })
     }
